@@ -32,7 +32,12 @@ function map_meta_cap( $cap, $user_id ) {
 
 	switch ( $cap ) {
 	case 'remove_user':
-		$caps[] = 'remove_users';
+		// In multisite the user must be a super admin to remove themselves.
+		if ( isset( $args[0] ) && $user_id == $args[0] && ! is_super_admin( $user_id ) ) {
+			$caps[] = 'do_not_allow';
+		} else {
+			$caps[] = 'remove_users';
+		}
 		break;
 	case 'promote_user':
 	case 'add_users':
@@ -114,6 +119,15 @@ function map_meta_cap( $cap, $user_id ) {
 				$caps[] = $post_type->cap->delete_private_posts;
 			}
 		}
+
+		/*
+		 * Setting the privacy policy page requires `manage_privacy_options`,
+		 * so deleting it should require that too.
+		 */
+		if ( (int) get_option( 'wp_page_for_privacy_policy' ) === $post->ID ) {
+			$caps = array_merge( $caps, map_meta_cap( 'manage_privacy_options', $user_id ) );
+		}
+
 		break;
 		// edit_post breaks down to edit_posts, edit_published_posts, or
 		// edit_others_posts
@@ -175,6 +189,15 @@ function map_meta_cap( $cap, $user_id ) {
 				$caps[] = $post_type->cap->edit_private_posts;
 			}
 		}
+
+		/*
+		 * Setting the privacy policy page requires `manage_privacy_options`,
+		 * so editing it should require that too.
+		 */
+		if ( (int) get_option( 'wp_page_for_privacy_policy' ) === $post->ID ) {
+			$caps = array_merge( $caps, map_meta_cap( 'manage_privacy_options', $user_id ) );
+		}
+
 		break;
 	case 'read_post':
 	case 'read_page':
@@ -253,46 +276,9 @@ function map_meta_cap( $cap, $user_id ) {
 	case 'add_user_meta':
 		list( $_, $object_type, $_ ) = explode( '_', $cap );
 		$object_id = (int) $args[0];
+		$object_subtype = get_object_subtype( $object_type, $object_id );
 
-		switch ( $object_type ) {
-			case 'post':
-				$post = get_post( $object_id );
-				if ( ! $post ) {
-					break;
-				}
-
-				$sub_type = get_post_type( $post );
-				break;
-
-			case 'comment':
-				$comment = get_comment( $object_id );
-				if ( ! $comment ) {
-					break;
-				}
-
-				$sub_type = empty( $comment->comment_type ) ? 'comment' : $comment->comment_type;
-				break;
-
-			case 'term':
-				$term = get_term( $object_id );
-				if ( ! $term ) {
-					break;
-				}
-
-				$sub_type = $term->taxonomy;
-				break;
-
-			case 'user':
-				$user = get_user_by( 'id', $object_id );
-				if ( ! $user ) {
-					break;
-				}
-
-				$sub_type = 'user';
-				break;
-		}
-
-		if ( empty( $sub_type ) ) {
+		if ( empty( $object_subtype ) ) {
 			$caps[] = 'do_not_allow';
 			break;
 		}
@@ -301,19 +287,79 @@ function map_meta_cap( $cap, $user_id ) {
 
 		$meta_key = isset( $args[1] ) ? $args[1] : false;
 
-		$has_filter = has_filter( "auth_{$object_type}_meta_{$meta_key}" ) || has_filter( "auth_{$object_type}_{$sub_type}_meta_{$meta_key}" );
-		if ( $meta_key && $has_filter ) {
-			/** This filter is documented in wp-includes/meta.php */
-			$allowed = apply_filters( "auth_{$object_type}_meta_{$meta_key}", false, $meta_key, $object_id, $user_id, $cap, $caps );
+		if ( $meta_key ) {
+			$allowed = ! is_protected_meta( $meta_key, $object_type );
 
-			/** This filter is documented in wp-includes/meta.php */
-			$allowed = apply_filters( "auth_{$object_type}_{$sub_type}_meta_{$meta_key}", $allowed, $meta_key, $object_id, $user_id, $cap, $caps );
+			if ( ! empty( $object_subtype ) && has_filter( "auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}" ) ) {
+
+				/**
+				 * Filters whether the user is allowed to edit a specific meta key of a specific object type and subtype.
+				 *
+				 * The dynamic portions of the hook name, `$object_type`, `$meta_key`,
+				 * and `$object_subtype`, refer to the metadata object type (comment, post, term or user),
+				 * the meta key value, and the object subtype respectively.
+				 *
+				 * @since 4.9.8
+				 *
+				 * @param bool     $allowed   Whether the user can add the object meta. Default false.
+				 * @param string   $meta_key  The meta key.
+				 * @param int      $object_id Object ID.
+				 * @param int      $user_id   User ID.
+				 * @param string   $cap       Capability name.
+				 * @param string[] $caps      Array of the user's capabilities.
+				 */
+				$allowed = apply_filters( "auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}", $allowed, $meta_key, $object_id, $user_id, $cap, $caps );
+			} else {
+
+				/**
+				 * Filters whether the user is allowed to edit a specific meta key of a specific object type.
+				 *
+				 * Return true to have the mapped meta caps from `edit_{$object_type}` apply.
+				 *
+				 * The dynamic portion of the hook name, `$object_type` refers to the object type being filtered.
+				 * The dynamic portion of the hook name, `$meta_key`, refers to the meta key passed to map_meta_cap().
+				 *
+				 * @since 3.3.0 As `auth_post_meta_{$meta_key}`.
+				 * @since 4.6.0
+				 *
+				 * @param bool     $allowed   Whether the user can add the object meta. Default false.
+				 * @param string   $meta_key  The meta key.
+				 * @param int      $object_id Object ID.
+				 * @param int      $user_id   User ID.
+				 * @param string   $cap       Capability name.
+				 * @param string[] $caps      Array of the user's capabilities.
+				 */
+				$allowed = apply_filters( "auth_{$object_type}_meta_{$meta_key}", $allowed, $meta_key, $object_id, $user_id, $cap, $caps );
+			}
+
+			if ( ! empty( $object_subtype ) ) {
+
+				/**
+				 * Filters whether the user is allowed to edit meta for specific object types/subtypes.
+				 *
+				 * Return true to have the mapped meta caps from `edit_{$object_type}` apply.
+				 *
+				 * The dynamic portion of the hook name, `$object_type` refers to the object type being filtered.
+				 * The dynamic portion of the hook name, `$object_subtype` refers to the object subtype being filtered.
+				 * The dynamic portion of the hook name, `$meta_key`, refers to the meta key passed to map_meta_cap().
+				 *
+				 * @since 4.6.0 As `auth_post_{$post_type}_meta_{$meta_key}`.
+				 * @since 4.7.0
+				 * @deprecated 4.9.8 Use `auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}`
+				 *
+				 * @param bool     $allowed   Whether the user can add the object meta. Default false.
+				 * @param string   $meta_key  The meta key.
+				 * @param int      $object_id Object ID.
+				 * @param int      $user_id   User ID.
+				 * @param string   $cap       Capability name.
+				 * @param string[] $caps      Array of the user's capabilities.
+				 */
+				$allowed = apply_filters_deprecated( "auth_{$object_type}_{$object_subtype}_meta_{$meta_key}", array( $allowed, $meta_key, $object_id, $user_id, $cap, $caps ), '4.9.8', "auth_{$object_type}_meta_{$meta_key}_for_{$object_subtype}" );
+			}
 
 			if ( ! $allowed ) {
 				$caps[] = $cap;
 			}
-		} elseif ( $meta_key && is_protected_meta( $meta_key, $object_type ) ) {
-			$caps[] = $cap;
 		}
 		break;
 	case 'edit_comment':
@@ -357,7 +403,7 @@ function map_meta_cap( $cap, $user_id ) {
 		// Disallow the file editors.
 		if ( defined( 'DISALLOW_FILE_EDIT' ) && DISALLOW_FILE_EDIT )
 			$caps[] = 'do_not_allow';
-		elseif ( defined( 'DISALLOW_FILE_MODS' ) && DISALLOW_FILE_MODS )
+		elseif ( ! wp_is_file_mod_allowed( 'capability_edit_themes' ) )
 			$caps[] = 'do_not_allow';
 		elseif ( is_multisite() && ! is_super_admin( $user_id ) )
 			$caps[] = 'do_not_allow';
@@ -375,7 +421,7 @@ function map_meta_cap( $cap, $user_id ) {
 	case 'update_core':
 		// Disallow anything that creates, deletes, or updates core, plugin, or theme files.
 		// Files in uploads are excepted.
-		if ( defined( 'DISALLOW_FILE_MODS' ) && DISALLOW_FILE_MODS ) {
+		if ( ! wp_is_file_mod_allowed( 'capability_update_core' ) ) {
 			$caps[] = 'do_not_allow';
 		} elseif ( is_multisite() && ! is_super_admin( $user_id ) ) {
 			$caps[] = 'do_not_allow';
@@ -387,8 +433,21 @@ function map_meta_cap( $cap, $user_id ) {
 			$caps[] = $cap;
 		}
 		break;
+	case 'install_languages':
+	case 'update_languages':
+		if ( ! wp_is_file_mod_allowed( 'can_install_language_pack' ) ) {
+			$caps[] = 'do_not_allow';
+		} elseif ( is_multisite() && ! is_super_admin( $user_id ) ) {
+			$caps[] = 'do_not_allow';
+		} else {
+			$caps[] = 'install_languages';
+		}
+		break;
 	case 'activate_plugins':
-		$caps[] = $cap;
+	case 'deactivate_plugins':
+	case 'activate_plugin':
+	case 'deactivate_plugin':
+		$caps[] = 'activate_plugins';
 		if ( is_multisite() ) {
 			// update_, install_, and delete_ are handled above with is_super_admin().
 			$menu_perms = get_site_option( 'menu_items', array() );
@@ -422,7 +481,11 @@ function map_meta_cap( $cap, $user_id ) {
 		$caps[] = 'edit_theme_options';
 		break;
 	case 'delete_site':
-		$caps[] = 'manage_options';
+		if ( is_multisite() ) {
+			$caps[] = 'manage_options';
+		} else {
+			$caps[] = 'do_not_allow';
+		}
 		break;
 	case 'edit_term':
 	case 'delete_term':
@@ -469,8 +532,21 @@ function map_meta_cap( $cap, $user_id ) {
 	case 'manage_network_plugins':
 	case 'manage_network_themes':
 	case 'manage_network_options':
+	case 'upgrade_network':
 		$caps[] = $cap;
 		break;
+	case 'setup_network':
+		if ( is_multisite() ) {
+			$caps[] = 'manage_network_options';
+		} else {
+			$caps[] = 'manage_options';
+		}
+		break;
+	case 'export_others_personal_data':
+	case 'erase_others_personal_data':
+	case 'manage_privacy_options':
+		$caps[] = is_multisite() ? 'manage_network' : 'manage_options';
+		break;
 	default:
 		// Handle meta capabilities for custom post types.
 		global $post_type_meta_caps;
@@ -479,6 +555,23 @@ function map_meta_cap( $cap, $user_id ) {
 			return call_user_func_array( 'map_meta_cap', $args );
 		}
 
+		// Block capabilities map to their post equivalent.
+		$block_caps = array(
+			'edit_blocks',
+			'edit_others_blocks',
+			'publish_blocks',
+			'read_private_blocks',
+			'delete_blocks',
+			'delete_private_blocks',
+			'delete_published_blocks',
+			'delete_others_blocks',
+			'edit_private_blocks',
+			'edit_published_blocks',
+		);
+		if ( in_array( $cap, $block_caps, true ) ) {
+			$cap = str_replace( '_blocks', '_posts', $cap );
+		}
+
 		// If no meta caps match, return the original cap.
 		$caps[] = $cap;
 	}
@@ -531,13 +624,13 @@ function current_user_can( $capability ) {
 }
 
 /**
- * Whether current user has a capability or role for a given site.
+ * Whether the current user has a specific capability for a given site.
  *
  * @since 3.0.0
  *
  * @param int    $blog_id    Site ID.
- * @param string $capability Capability or role name.
- * @return bool
+ * @param string $capability Capability name.
+ * @return bool Whether the user has the given capability.
  */
 function current_user_can_for_blog( $blog_id, $capability ) {
 	$switched = is_multisite() ? switch_to_blog( $blog_id ) : false;
@@ -564,13 +657,13 @@ function current_user_can_for_blog( $blog_id, $capability ) {
 }
 
 /**
- * Whether author of supplied post has capability or role.
+ * Whether the author of the supplied post has a specific capability.
  *
  * @since 2.9.0
  *
- * @param int|object $post Post ID or post object.
- * @param string $capability Capability or role name.
- * @return bool
+ * @param int|WP_Post $post       Post ID or post object.
+ * @param string      $capability Capability name.
+ * @return bool Whether the post author has the given capability.
  */
 function author_can( $post, $capability ) {
 	if ( !$post = get_post($post) )
@@ -588,13 +681,13 @@ function author_can( $post, $capability ) {
 }
 
 /**
- * Whether a particular user has capability or role.
+ * Whether a particular user has a specific capability.
  *
  * @since 3.1.0
  *
- * @param int|object $user User ID or object.
- * @param string $capability Capability or role name.
- * @return bool
+ * @param int|WP_User $user       User ID or object.
+ * @param string      $capability Capability name.
+ * @return bool Whether the user has the given capability.
  */
 function user_can( $user, $capability ) {
 	if ( ! is_object( $user ) )
@@ -809,3 +902,22 @@ function revoke_super_admin( $user_id ) {
 	}
 	return false;
 }
+
+/**
+ * Filters the user capabilities to grant the 'install_languages' capability as necessary.
+ *
+ * A user must have at least one out of the 'update_core', 'install_plugins', and
+ * 'install_themes' capabilities to qualify for 'install_languages'.
+ *
+ * @since 4.9.0
+ *
+ * @param array $allcaps An array of all the user's capabilities.
+ * @return array Filtered array of the user's capabilities.
+ */
+function wp_maybe_grant_install_languages_cap( $allcaps ) {
+	if ( ! empty( $allcaps['update_core'] ) || ! empty( $allcaps['install_plugins'] ) || ! empty( $allcaps['install_themes'] ) ) {
+		$allcaps['install_languages'] = true;
+	}
+
+	return $allcaps;
+}
