@@ -14,7 +14,7 @@ window.wp = window.wp || {};
 	 *
 	 * The Plupload library provides cross-browser uploader UI integration.
 	 * This object bridges the Plupload API to integrate uploads into the
-	 * WordPress back-end and the WordPress media experience.
+	 * WordPress back end and the WordPress media experience.
 	 *
 	 * @param {object} options           The options passed to the new plupload instance.
 	 * @param {object} options.container The id of uploader container.
@@ -180,6 +180,11 @@ window.wp = window.wp || {};
 			$(self).trigger( 'uploader:ready' );
 		});
 
+		this.uploader.bind( 'postinit', function( up ) {
+			up.refresh();
+			self.init();
+		});
+
 		this.uploader.init();
 
 		if ( this.browser ) {
@@ -193,7 +198,6 @@ window.wp = window.wp || {};
 		/**
 		 * After files were filtered and added to the queue, create a model for each.
 		 *
-		 * @event FilesAdded
 		 * @param {plupload.Uploader} uploader Uploader instance.
 		 * @param {Array}             files    Array of file objects that were added to queue by the user.
 		 */
@@ -311,9 +315,6 @@ window.wp = window.wp || {};
 			up.refresh();
 		});
 
-		this.uploader.bind( 'PostInit', function() {
-			self.init();
-		});
 	};
 
 	// Adds the 'defaults' and 'browser' properties.
@@ -338,7 +339,7 @@ window.wp = window.wp || {};
 		}
 	};
 
-	$.extend( Uploader.prototype, {
+	$.extend( Uploader.prototype, /** @lends wp.Uploader.prototype */{
 		/**
 		 * Acts as a shortcut to extending the uploader's multipart_params object.
 		 *
